@@ -148,7 +148,7 @@ use strict;
     PVIP_NODE_JUNCTIVE_OR
     PVIP_NODE_UNICODE_CHAR
     PVIP_NODE_STUB
-    PVIP_NODE_EXPORTABLE
+    PVIP_NODE_EXPORT
     PVIP_NODE_PARAM
     PVIP_NODE_BITWISE_OR
     PVIP_NODE_BITWISE_AND
@@ -160,6 +160,10 @@ use strict;
     PVIP_NODE_RAND
     PVIP_NODE_END
     PVIP_NODE_BEGIN
+    PVIP_NODE_IS_DIVISIBLE_BY
+    PVIP_NODE_NOT_DIVISIBLE_BY
+    PVIP_NODE_CONTAINER_IDENTITY
+    PVIP_NODE_Z
     PVIP_CATEGORY_UNKNOWN
     PVIP_CATEGORY_STRING
     PVIP_CATEGORY_INT
